@@ -10,13 +10,13 @@ import ssl
 import sys
 import tempfile
 import tarfile
-import json
 
 import base64
 import copy
 
+import yaml
+
 from . import acc_provision
-from . import fake_apic
 
 from ruamel.yaml import YAML
 yml = YAML()
@@ -645,6 +645,54 @@ def test_flavor_openshift_414_openstack():
     )
 
 
+@in_testdir
+def test_flavor_openshift_415_openstack():
+    run_provision(
+        "flavor_openshift_415_openstack.inp.yaml",
+        "flavor_openshift_415_openstack.kube.yaml",
+        "flavor_openshift_415_openstack_tar",
+        None,
+        "flavor_openshift_415_openstack.apic.txt",
+        overrides={"flavor": "openshift-4.15-openstack"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_416_openstack():
+    run_provision(
+        "flavor_openshift_416_openstack.inp.yaml",
+        "flavor_openshift_416_openstack.kube.yaml",
+        "flavor_openshift_416_openstack_tar",
+        None,
+        "flavor_openshift_416_openstack.apic.txt",
+        overrides={"flavor": "openshift-4.16-openstack"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_417_openstack():
+    run_provision(
+        "flavor_openshift_417_openstack.inp.yaml",
+        "flavor_openshift_417_openstack.kube.yaml",
+        "flavor_openshift_417_openstack_tar",
+        None,
+        "flavor_openshift_417_openstack.apic.txt",
+        overrides={"flavor": "openshift-4.17-openstack"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_418_openstack():
+    run_provision(
+        "flavor_openshift_418_openstack.inp.yaml",
+        "flavor_openshift_418_openstack.kube.yaml",
+        "flavor_openshift_418_openstack_tar",
+        None,
+        "flavor_openshift_418_openstack.apic.txt",
+        overrides={"flavor": "openshift-4.18-openstack"}
+    )
+
+
 @in_testdir
 def test_flavor_openshift_47_esx():
     run_provision(
@@ -717,6 +765,54 @@ def test_flavor_openshift_412_esx():
     )
 
 
+@in_testdir
+def test_flavor_openshift_417_agent_based_esx():
+    run_provision(
+        "flavor_openshift_417_agent_based_esx.inp.yaml",
+        "flavor_openshift_417_agent_based_esx.kube.yaml",
+        "flavor_openshift_417_agent_based_esx_tar",
+        None,
+        "flavor_openshift_417_agent_based_esx.apic.txt",
+        overrides={"flavor": "openshift-4.17-agent-based-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_418_agent_based_esx():
+    run_provision(
+        "flavor_openshift_418_agent_based_esx.inp.yaml",
+        "flavor_openshift_418_agent_based_esx.kube.yaml",
+        "flavor_openshift_418_agent_based_esx_tar",
+        None,
+        "flavor_openshift_418_agent_based_esx.apic.txt",
+        overrides={"flavor": "openshift-4.18-agent-based-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_416_agent_based_esx():
+    run_provision(
+        "flavor_openshift_416_agent_based_esx.inp.yaml",
+        "flavor_openshift_416_agent_based_esx.kube.yaml",
+        "flavor_openshift_416_agent_based_esx_tar",
+        None,
+        "flavor_openshift_416_agent_based_esx.apic.txt",
+        overrides={"flavor": "openshift-4.16-agent-based-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_415_agent_based_esx():
+    run_provision(
+        "flavor_openshift_415_agent_based_esx.inp.yaml",
+        "flavor_openshift_415_agent_based_esx.kube.yaml",
+        "flavor_openshift_415_agent_based_esx_tar",
+        None,
+        "flavor_openshift_415_agent_based_esx.apic.txt",
+        overrides={"flavor": "openshift-4.15-agent-based-esx"}
+    )
+
+
 @in_testdir
 def test_flavor_openshift_414_agent_based_esx():
     run_provision(
@@ -753,6 +849,150 @@ def test_flv_openshift_414_esx():
     )
 
 
+@in_testdir
+def test_flavor_openshift_417_agent_based_baremetal():
+    run_provision(
+        "flavor_openshift_417_agent_based_baremetal.inp.yaml",
+        "flavor_openshift_417_agent_based_baremetal.kube.yaml",
+        "flavor_openshift_417_agent_based_baremetal_tar",
+        None,
+        "flavor_openshift_417_agent_based_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.17-agent-based-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_418_agent_based_baremetal():
+    run_provision(
+        "flavor_openshift_418_agent_based_baremetal.inp.yaml",
+        "flavor_openshift_418_agent_based_baremetal.kube.yaml",
+        "flavor_openshift_418_agent_based_baremetal_tar",
+        None,
+        "flavor_openshift_418_agent_based_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.18-agent-based-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_416_agent_based_baremetal():
+    run_provision(
+        "flavor_openshift_416_agent_based_baremetal.inp.yaml",
+        "flavor_openshift_416_agent_based_baremetal.kube.yaml",
+        "flavor_openshift_416_agent_based_baremetal_tar",
+        None,
+        "flavor_openshift_416_agent_based_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.16-agent-based-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_415_esx():
+    run_provision(
+        "flavor_openshift_415_esx.inp.yaml",
+        "flavor_openshift_415_esx.kube.yaml",
+        "flavor_openshift_415_esx_tar",
+        None,
+        "flavor_openshift_415_esx.apic.txt",
+        overrides={"flavor": "openshift-4.15-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_416_esx():
+    run_provision(
+        "flavor_openshift_416_esx.inp.yaml",
+        "flavor_openshift_416_esx.kube.yaml",
+        "flavor_openshift_416_esx_tar",
+        None,
+        "flavor_openshift_416_esx.apic.txt",
+        overrides={"flavor": "openshift-4.16-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_417_esx():
+    run_provision(
+        "flavor_openshift_417_esx.inp.yaml",
+        "flavor_openshift_417_esx.kube.yaml",
+        "flavor_openshift_417_esx_tar",
+        None,
+        "flavor_openshift_417_esx.apic.txt",
+        overrides={"flavor": "openshift-4.17-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_418_esx():
+    run_provision(
+        "flavor_openshift_418_esx.inp.yaml",
+        "flavor_openshift_418_esx.kube.yaml",
+        "flavor_openshift_418_esx_tar",
+        None,
+        "flavor_openshift_418_esx.apic.txt",
+        overrides={"flavor": "openshift-4.18-esx"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_415_baremetal():
+    run_provision(
+        "flavor_openshift_415_baremetal.inp.yaml",
+        "flavor_openshift_415_baremetal.kube.yaml",
+        "flavor_openshift_415_baremetal_tar",
+        None,
+        "flavor_openshift_415_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.15-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_416_baremetal():
+    run_provision(
+        "flavor_openshift_416_baremetal.inp.yaml",
+        "flavor_openshift_416_baremetal.kube.yaml",
+        "flavor_openshift_416_baremetal_tar",
+        None,
+        "flavor_openshift_416_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.16-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_417_baremetal():
+    run_provision(
+        "flavor_openshift_417_baremetal.inp.yaml",
+        "flavor_openshift_417_baremetal.kube.yaml",
+        "flavor_openshift_417_baremetal_tar",
+        None,
+        "flavor_openshift_417_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.17-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_418_baremetal():
+    run_provision(
+        "flavor_openshift_418_baremetal.inp.yaml",
+        "flavor_openshift_418_baremetal.kube.yaml",
+        "flavor_openshift_418_baremetal_tar",
+        None,
+        "flavor_openshift_418_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.18-baremetal"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_415_agent_based_baremetal():
+    run_provision(
+        "flavor_openshift_415_agent_based_baremetal.inp.yaml",
+        "flavor_openshift_415_agent_based_baremetal.kube.yaml",
+        "flavor_openshift_415_agent_based_baremetal_tar",
+        None,
+        "flavor_openshift_415_agent_based_baremetal.apic.txt",
+        overrides={"flavor": "openshift-4.15-agent-based-baremetal"}
+    )
+
+
 @in_testdir
 def test_flavor_openshift_414_agent_based_baremetal():
     run_provision(
@@ -945,6 +1185,42 @@ def test_chained_mode_ovs_cni_support():
     )
 
 
+@in_testdir
+def test_override_enable_container_l3_peering_model():
+    run_provision(
+        "override_enable_container_l3_peering_model.inp.yaml",
+        "override_enable_container_l3_peering_model.kube.yaml",
+        None,
+        None,
+        "override_enable_container_l3_peering_model.apic.txt",
+        overrides={"flavor": "openshift-sdn-ovn-baremetal"}
+    )
+
+
+@in_testdir
+def test_override_include_network_attachment_definition_crd():
+    run_provision(
+        "override_include_network_attachment_definition_crd.inp.yaml",
+        "override_include_network_attachment_definition_crd.kube.yaml",
+        None,
+        None,
+        "override_include_network_attachment_definition_crd.apic.txt",
+        overrides={"flavor": "openshift-sdn-ovn-baremetal"}
+    )
+
+
+@in_testdir
+def test_override_use_system_id_for_secondary_names():
+    run_provision(
+        "override_use_system_id_for_secondary_names.inp.yaml",
+        "override_use_system_id_for_secondary_names.kube.yaml",
+        None,
+        None,
+        "override_use_system_id_for_secondary_names.apic.txt",
+        overrides={"flavor": "openshift-sdn-ovn-baremetal"}
+    )
+
+
 @in_testdir
 def test_flavor_openshift_411_baremetal():
     run_provision(
@@ -1077,140 +1353,6 @@ def test_flavor_localhost():
     )
 
 
-@in_testdir
-def test_flavor_cloud_base():
-
-    with open("apic_test_data.json") as data_file:
-        data = json.loads(data_file.read())
-    apic = fake_apic.start_fake_apic(50000, data["gets"], data["deletes"])
-
-    def clean_apic():
-        apic.shutdown()
-        return False
-
-    run_provision(
-        "flavor_cloud.inp.yaml",
-        "flavor_cloud.kube.yaml",
-        "cloud_tar",
-        None,
-        overrides={"flavor": "cloud", "apic": True, "password": "test"},
-        cleanupFunc=clean_apic
-    )
-    apic.shutdown()
-
-
-@in_testdir
-def test_flavor_aks_base():
-    with open("apic_aks_test_data.json") as data_file:
-        data = json.loads(data_file.read())
-    apic = fake_apic.start_fake_apic(50001, data["gets"], data["deletes"])
-
-    def clean_apic():
-        apic.shutdown()
-        return False
-
-    run_provision(
-        "flavor_aks.inp.yaml",
-        "flavor_aks.kube.yaml",
-        None,
-        None,
-        overrides={"flavor": "aks", "apic": True, "password": "test"},
-        cleanupFunc=clean_apic
-    )
-    apic.shutdown()
-
-
-@in_testdir
-def test_flavor_eks_base():
-    with open("apic_eks_test_data.json") as data_file:
-        data = json.loads(data_file.read())
-    apic = fake_apic.start_fake_apic(50002, data["gets"], data["deletes"])
-
-    def clean_apic():
-        apic.shutdown()
-        return False
-
-    run_provision(
-        "flavor_eks.inp.yaml",
-        "flavor_eks.kube.yaml",
-        None,
-        None,
-        overrides={"flavor": "eks", "apic": True, "password": "test"},
-        cleanupFunc=clean_apic
-    )
-    apic.shutdown()
-
-
-@in_testdir
-def test_flavor_cloud_delete():
-    with open("apic_delete_data.json") as data_file:
-        data = json.loads(data_file.read())
-    apic = fake_apic.start_fake_apic(50000, data["gets"], data["deletes"])
-
-    def clean_apic():
-        apic.shutdown()
-        return False
-
-    assert (len(fake_apic.fake_deletes) != 0)
-    run_provision(
-        "flavor_cloud.inp.yaml",
-        None,
-        None,
-        None,
-        overrides={"flavor": "cloud", "apic": True, "password": "test", "delete": True},
-        cleanupFunc=clean_apic
-    )
-    apic.shutdown()
-    # verify all deletes were executed
-    assert (len(fake_apic.fake_deletes) == 0)
-
-
-@in_testdir
-def test_flavor_aks_delete():
-    with open("apic_aks_delete_data.json") as data_file:
-        data = json.loads(data_file.read())
-    apic = fake_apic.start_fake_apic(50001, data["gets"], data["deletes"])
-
-    def clean_apic():
-        apic.shutdown()
-        return False
-
-    assert (len(fake_apic.fake_deletes) != 0)
-    run_provision(
-        "flavor_aks.inp.yaml",
-        None,
-        None,
-        None,
-        overrides={"flavor": "aks", "apic": True, "password": "test", "delete": True}, cleanupFunc=clean_apic
-    )
-    apic.shutdown()
-    # verify all deletes were executed
-    assert (len(fake_apic.fake_deletes) == 0)
-
-
-@in_testdir
-def test_flavor_eks_delete():
-    with open("apic_eks_delete_data.json") as data_file:
-        data = json.loads(data_file.read())
-    apic = fake_apic.start_fake_apic(50002, data["gets"], data["deletes"])
-
-    def clean_apic():
-        apic.shutdown()
-        return False
-
-    assert (len(fake_apic.fake_deletes) != 0)
-    run_provision(
-        "flavor_eks.inp.yaml",
-        None,
-        None,
-        None,
-        overrides={"flavor": "eks", "apic": True, "password": "test", "delete": True}, cleanupFunc=clean_apic
-    )
-    apic.shutdown()
-    # verify all deletes were executed
-    assert (len(fake_apic.fake_deletes) == 0)
-
-
 @in_testdir
 def test_conflicting_infravlan():
     run_provision(
@@ -1409,6 +1551,54 @@ def test_flavor_RKE2_kubernetes_1_27_base():
     )
 
 
+@in_testdir
+def test_flavor_RKE2_kubernetes_1_28_base():
+    run_provision(
+        "flavor_RKE2_kubernetes_1_28.inp.yaml",
+        "flavor_RKE2_kubernetes_1_28.kube.yaml",
+        None,
+        None,
+        "flavor_RKE2_kubernetes_1_28.apic.txt",
+        overrides={"flavor": "RKE2-kubernetes-1.28"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE2_kubernetes_1_29_base():
+    run_provision(
+        "flavor_RKE2_kubernetes_1_29.inp.yaml",
+        "flavor_RKE2_kubernetes_1_29.kube.yaml",
+        None,
+        None,
+        "flavor_RKE2_kubernetes_1_29.apic.txt",
+        overrides={"flavor": "RKE2-kubernetes-1.29"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE2_kubernetes_1_30_base():
+    run_provision(
+        "flavor_RKE2_kubernetes_1_30.inp.yaml",
+        "flavor_RKE2_kubernetes_1_30.kube.yaml",
+        None,
+        None,
+        "flavor_RKE2_kubernetes_1_30.apic.txt",
+        overrides={"flavor": "RKE2-kubernetes-1.30"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE2_kubernetes_1_31_base():
+    run_provision(
+        "flavor_RKE2_kubernetes_1_31.inp.yaml",
+        "flavor_RKE2_kubernetes_1_31.kube.yaml",
+        None,
+        None,
+        "flavor_RKE2_kubernetes_1_31.apic.txt",
+        overrides={"flavor": "RKE2-kubernetes-1.31"}
+    )
+
+
 @in_testdir
 def test_flavor_RKE_1_2_3_base():
     run_provision(
@@ -1541,6 +1731,198 @@ def test_flavor_RKE_1_5_3_base():
     )
 
 
+@in_testdir
+def test_flavor_RKE_1_4_16_base():
+    run_provision(
+        "flavor_RKE_1_4_16.inp.yaml",
+        "flavor_RKE_1_4_16.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_4_16.apic.txt",
+        overrides={"flavor": "RKE-1.4.16"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_5_6_base():
+    run_provision(
+        "flavor_RKE_1_5_6.inp.yaml",
+        "flavor_RKE_1_5_6.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_5_6.apic.txt",
+        overrides={"flavor": "RKE-1.5.6"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_4_20_base():
+    run_provision(
+        "flavor_RKE_1_4_20.inp.yaml",
+        "flavor_RKE_1_4_20.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_4_20.apic.txt",
+        overrides={"flavor": "RKE-1.4.20"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_5_11_base():
+    run_provision(
+        "flavor_RKE_1_5_11.inp.yaml",
+        "flavor_RKE_1_5_11.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_5_11.apic.txt",
+        overrides={"flavor": "RKE-1.5.11"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_6_0_base():
+    run_provision(
+        "flavor_RKE_1_6_0.inp.yaml",
+        "flavor_RKE_1_6_0.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_6_0.apic.txt",
+        overrides={"flavor": "RKE-1.6.0"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_5_13_base():
+    run_provision(
+        "flavor_RKE_1_5_13.inp.yaml",
+        "flavor_RKE_1_5_13.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_5_13.apic.txt",
+        overrides={"flavor": "RKE-1.5.13"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_6_2_base():
+    run_provision(
+        "flavor_RKE_1_6_2.inp.yaml",
+        "flavor_RKE_1_6_2.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_6_2.apic.txt",
+        overrides={"flavor": "RKE-1.6.2"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_5_14_base():
+    run_provision(
+        "flavor_RKE_1_5_14.inp.yaml",
+        "flavor_RKE_1_5_14.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_5_14.apic.txt",
+        overrides={"flavor": "RKE-1.5.14"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_6_3_base():
+    run_provision(
+        "flavor_RKE_1_6_3.inp.yaml",
+        "flavor_RKE_1_6_3.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_6_3.apic.txt",
+        overrides={"flavor": "RKE-1.6.3"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_6_5_base():
+    run_provision(
+        "flavor_RKE_1_6_5.inp.yaml",
+        "flavor_RKE_1_6_5.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_6_5.apic.txt",
+        overrides={"flavor": "RKE-1.6.5"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_7_1_base():
+    run_provision(
+        "flavor_RKE_1_7_1.inp.yaml",
+        "flavor_RKE_1_7_1.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_7_1.apic.txt",
+        overrides={"flavor": "RKE-1.7.1"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_6_6_base():
+    run_provision(
+        "flavor_RKE_1_6_6.inp.yaml",
+        "flavor_RKE_1_6_6.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_6_6.apic.txt",
+        overrides={"flavor": "RKE-1.6.6"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_7_2_base():
+    run_provision(
+        "flavor_RKE_1_7_2.inp.yaml",
+        "flavor_RKE_1_7_2.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_7_2.apic.txt",
+        overrides={"flavor": "RKE-1.7.2"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_6_10_base():
+    run_provision(
+        "flavor_RKE_1_6_10.inp.yaml",
+        "flavor_RKE_1_6_10.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_6_10.apic.txt",
+        overrides={"flavor": "RKE-1.6.10"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_7_7_base():
+    run_provision(
+        "flavor_RKE_1_7_7.inp.yaml",
+        "flavor_RKE_1_7_7.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_7_7.apic.txt",
+        overrides={"flavor": "RKE-1.7.7"}
+    )
+
+
+@in_testdir
+def test_flavor_RKE_1_8_3_base():
+    run_provision(
+        "flavor_RKE_1_8_3.inp.yaml",
+        "flavor_RKE_1_8_3.rke.yaml",
+        None,
+        None,
+        "flavor_RKE_1_8_3.apic.txt",
+        overrides={"flavor": "RKE-1.8.3"}
+    )
+
+
 @in_testdir
 def test_sample():
     with tempfile.NamedTemporaryFile("wb") as tmpout:
@@ -1697,6 +2079,52 @@ def test_flvr_calico_3_26_3_multiple_vrf_uc1():
     )
 
 
+@in_testdir
+def test_flavor_k8s_aci_cilium():
+    run_provision(
+        "flavor_k8s_aci_cilium.inp.yaml",
+        "flavor_k8s_aci_cilium.kube.yaml",
+        "flavor_k8s_aci_cilium_tar",
+        None,
+        "flavor_k8s_aci_cilium.apic.txt",
+        overrides={"flavor": "k8s-aci-cilium"}
+    )
+
+
+@in_testdir
+def test_flavor_openshift_414_aci_cilium_esx():
+    run_provision(
+        "flavor_openshift_414_aci_cilium_esx.inp.yaml",
+        "flavor_openshift_414_aci_cilium_esx.kube.yaml",
+        "flavor_openshift_414_aci_cilium_esx_tar",
+        None,
+        "flavor_openshift_414_aci_cilium_esx.apic.txt",
+        overrides={"flavor": "openshift-4.14-aci-cilium-esx"}
+    )
+
+
+@in_testdir
+def test_aci_cilium_chaining():
+    run_provision(
+        "enable_aci_cilium_chaining.inp.yaml",
+        "enable_aci_cilium_chaining.kube.yaml",
+        None,
+        None,
+        "enable_aci_cilium_chaining.apic.txt",
+    )
+
+
+@in_testdir
+def test_acc_provision_operator_exclude():
+    run_provision(
+        "acc_provision_operator_exclude.inp.yaml",
+        "acc_provision_operator_exclude.kube.yaml",
+        None,
+        None,
+        None,
+    )
+
+
 @in_testdir
 def test_flvr_calico_3_26_3_multiple_vrf_uc2():
     run_provision(
@@ -1905,11 +2333,9 @@ def get_args(**overrides):
         "timeout": None,
         "debug": True,
         "list_flavors": False,
-        "flavor": "kubernetes-1.29",
+        "flavor": "kubernetes-1.30",
         "version_token": "dummy",
         "release": False,
-        "test_data_out": None,
-        "skip_kafka_certs": True,
         "upgrade": False,
         "disable_multus": 'true',
         "operator_mode": False,
@@ -1923,7 +2349,8 @@ def get_args(**overrides):
         "apic_oobm_ip": None,
         "test_run": True,
         "compare_kube_yaml_aci_op_cm_in_plain_text": True,
-        "skip_app_profile_check": False
+        "skip_app_profile_check": False,
+        "old_nad_vlan_map_input": None
     }
     argc = collections.namedtuple('argc', list(arg.keys()))
     args = argc(**arg)
@@ -2161,3 +2588,17 @@ def create_certificate(input_file, cert_file, **overrides):
         assert cert_data['issuer'][1][0][1] == 'Cisco Systems'
     finally:
         os.chdir(old_working_directory)
+
+
+@in_testdir
+def test_yaml_strip():
+    # test that yaml.safe_load/yaml.safe_dump strips whitespace and
+    # comments as expected. This pattern will be used to reduce
+    # the size of vmmInjectedClusterDetails.accProvisionInput
+    # posted to APIC as it's limited to 8192 chars
+    config_file = "flavor_localhost.inp.yaml"
+    user_config = acc_provision.config_user("", config_file)
+    input_yaml = yaml.safe_load(user_config["user_input"])
+    acc_provision_input = yaml.safe_dump(input_yaml, sort_keys=False)
+    assert len(user_config["user_input"]) > len(acc_provision_input)
+    assert acc_provision_input != user_config["user_input"]
